==> nextcloud-29.0.5.tgz: nextcloud/apps/viewer/l10n/ru.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Просмотр изображений",
    "Simple file viewer with slideshow for media" : "Простое приложение для просмотра файлов изображений и видео  с поддержкой функции слайд-шоу",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Вы можете показать свои последние праздничные фотографии и видео, прямо как в фильмах! Вы можете показать свой последний роман прямо из вашего Nextcloud! Вы можете выбрать лучший GIF из вашей коллекции благодаря непосредственному предварительному просмотру ваших избранных файлов и многое другое!",
    "Your browser does not support audio." : "Используемый браузер не поддерживает воспроизведение звука.",
    "Error loading {name}" : "Ошибка при загрузке файла «{name}»",
    "Image saved" : "Изображение сохранено",
    "Error saving image" : "Не удалось сохранить изображение",
    "Unsaved changes" : "Несохранённые изменения",
    "Drop changes" : "Отменить изменения",
    "LIVE" : "ТРАНСЛИРУЕТСЯ",
    "Your browser does not support videos." : "Используемый браузер не поддерживает воспроизведение видео.",
    "Edit" : "Редактировать",
    "Exit full screen" : "Выйти из полноэкранного режима",
    "Full screen" : "Во весь экран",
    "Open sidebar" : "Открыть боковую панель",
    "Download" : "Скачать",
    "Delete" : "Удалить",
    "This file no longer exists" : "Этот файл более не существует",
    "There is no plugin available to display this file type" : "Нет доступного плагина для отображения этого типа файла",
    "View" : "Просмотр",
    "Name" : "Имя",
    "Save" : "Сохранить",
    "Save as" : "Сохранить как",
    "Back" : "Назад",
    "Loading …" : "Загрузка…",
    "Reset" : "Сброс",
    "All changes will be lost." : "Изменения не будут сохранены.",
    "Are you sure you want to continue?" : "Продолжить?",
    "Cancel" : "Отменить",
    "Continue" : "Продолжить",
    "Undo" : "Отменить",
    "Redo" : "Повторить",
    "Show original image" : "Показать исходное изображение",
    "Zoom in" : "Приблизить",
    "Zoom out" : "Отдалить",
    "Toggle zoom menu" : "Меню мастшабирования",
    "Adjust" : "Настроить",
    "Fine-tune" : "Обработка",
    "Filters" : "Фильтры",
    "Watermark" : "Водяной знак",
    "Draw" : "Рисование",
    "Resize" : "Размер",
    "Invalid image." : "Неверный формат изображения.",
    "Error while uploading the image." : "Не удалось передать изображение на сервер.",
    "are not images" : "не являются изображениями",
    "is not an image" : "не является изображением",
    "to be uploaded" : "для загрузки на сервер",
    "Crop" : "Обрезать",
    "Original" : "Исходное",
    "Custom" : "Задать",
    "Square" : "Квадрат",
    "Landscape" : "Ландшафтное",
    "Portrait" : "Портретное",
    "Ellipse" : "Эллипс",
    "Classic TV" : "Классическое ТВ",
    "CinemaScope" : "Синемаскоп",
    "Arrow" : "Стрела",
    "Blur" : "Размытие",
    "Brightness" : "Яркость",
    "Contrast" : "Контраст",
    "Un-flip X" : "Отразить по горизонтали",
    "Flip X" : "Отразить по горизонтали",
    "Un-flip Y" : "Отразить по вертикали",
    "Flip Y" : "Отразить по вертикали",
    "HSV" : "HSV (Тон, насыщенность, значение)",
    "Hue" : "Тон",
    "Saturation" : "Насыщенность",
    "Value" : "Значение",
    "Image" : "Изображение",
    "Importing …" : "Импорт…",
    "+ Add image" : "+ Добавить изображение",
    "Line" : "Линия",
    "Pen" : "Ручка",
    "Polygon" : "Многоугольник",
    "Sides" : "Количество сторон",
    "Rectangle" : "Прямоугольник",
    "Corner Radius" : "Радиус скругления",
    "Width in pixels" : "Ширина (пикс.)",
    "Height in pixels" : "Высота (пикс.)",
    "Toggle ratio lock" : "Блокировка соотношения сторон",
    "Reset to original image size" : "Вернуться с исходному размеру",
    "Rotate" : "Поворот",
    "Text" : "Текст",
    "Text spacing" : "Межстрочный интервал",
    "Text alignment" : "Выравнивание текста",
    "Font family" : "Гарнитура шрифта",
    "Size" : "Размер",
    "Letter spacing" : "Межсимвольный интервал",
    "Line height" : "Высота строки",
    "Warmth" : "Теплота",
    "+ Add watermark" : "+ Добавить водяной знак",
    "Choose watermark type" : "Выберите тип водяного знака",
    "Upload watermark" : "Загрузить водяной знак",
    "Add as text" : "Добавить как текст",
    "Padding" : "Отступы",
    "Shadow" : "Тень",
    "Horizontal" : "По горизонтали",
    "Vertical" : "По вертикали",
    "Opacity" : "Непрозрачность",
    "Position" : "Расположение",
    "Stroke" : "Зачёркнутый",
    "Save image as" : "Сохранить изображение как",
    "Extension" : "Расширение",
    "Name is required." : "Необходимо указать имя.",
    "Quality" : "Качество",
    "Saved image size (width x height)" : "Размер сохранённого изображения (ширина × высота)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Обратите внимание, что выбранная область обрезки меньше примененного изменения размера, что может привести к снижению качества",
    "Actual size (100%)" : "Фактический размер (100%)",
    "Fit size" : "По размеру окна"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/viewer/l10n/ru.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Просмотр изображений",
    "Simple file viewer with slideshow for media" : "Простое приложение для просмотра файлов изображений и видео  с поддержкой функции слайд-шоу",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Вы можете показать свои последние праздничные фотографии и видео, прямо как в фильмах! Вы можете показать свой последний роман прямо из вашего Nextcloud! Вы можете выбрать лучший GIF из вашей коллекции благодаря непосредственному предварительному просмотру ваших избранных файлов и многое другое!",
    "Your browser does not support audio." : "Используемый браузер не поддерживает воспроизведение звука.",
    "Error loading {name}" : "Ошибка при загрузке файла «{name}»",
    "Image saved" : "Изображение сохранено",
    "Error saving image" : "Не удалось сохранить изображение",
    "Unsaved changes" : "Несохранённые изменения",
    "Drop changes" : "Отменить изменения",
    "Play the live photo" : "Воспроизвести живое фото",
    "LIVE" : "ТРАНСЛИРУЕТСЯ",
    "Your browser does not support videos." : "Используемый браузер не поддерживает воспроизведение видео.",
    "Edit" : "Редактировать",
    "Exit full screen" : "Выйти из полноэкранного режима",
    "Full screen" : "Во весь экран",
    "Open sidebar" : "Открыть боковую панель",
    "Download" : "Скачать",
    "Delete" : "Удалить",
    "This file no longer exists" : "Этот файл более не существует",
    "There is no plugin available to display this file type" : "Нет доступного плагина для отображения этого типа файла",
    "View" : "Просмотр",
    "Name" : "Имя",
    "Save" : "Сохранить",
    "Save as" : "Сохранить как",
    "Back" : "Назад",
    "Loading …" : "Загрузка…",
    "Reset" : "Сброс",
    "All changes will be lost." : "Изменения не будут сохранены.",
    "Are you sure you want to continue?" : "Продолжить?",
    "Cancel" : "Отменить",
    "Apply" : "Применить",
    "Warning" : "Предупреждение",
    "Confirm" : "Подтвердить",
    "Discard changes" : "Отменить изменения",
    "Undo" : "Отменить",
    "Redo" : "Повторить",
    "Show original image" : "Показать исходное изображение",
    "Zoom in" : "Приблизить",
    "Zoom out" : "Отдалить",
    "Toggle zoom menu" : "Меню мастшабирования",
    "Adjust" : "Настроить",
    "Fine-tune" : "Обработка",
    "Filters" : "Фильтры",
    "Watermark" : "Водяной знак",
    "Draw" : "Рисование",
    "Resize" : "Размер",
    "Image name" : "Название изображения",
    "Invalid image." : "Неверный формат изображения.",
    "Error while uploading the image." : "Не удалось передать изображение на сервер.",
    "are not images" : "не являются изображениями",
    "is not an image" : "не является изображением",
    "to be uploaded" : "для загрузки на сервер",
    "Crop" : "Обрезать",
    "Original" : "Исходное",
    "Custom" : "Задать",
    "Square" : "Квадрат",
    "Landscape" : "Ландшафтное",
    "Portrait" : "Портретное",
    "Ellipse" : "Эллипс",
    "Classic TV" : "Классическое ТВ",
    "CinemaScope" : "Синемаскоп",
    "Arrow" : "Стрела",
    "Blur" : "Размытие",
    "Brightness" : "Яркость",
    "Contrast" : "Контраст",
    "Un-flip X" : "Отразить по горизонтали",
    "Flip X" : "Отразить по горизонтали",
    "Un-flip Y" : "Отразить по вертикали",
    "Flip Y" : "Отразить по вертикали",
    "HSV" : "HSV (Тон, насыщенность, значение)",
    "Hue" : "Тон",
    "Saturation" : "Насыщенность",
    "Value" : "Значение",
    "Image" : "Изображение",
    "Importing …" : "Импорт…",
    "+ Add image" : "+ Добавить изображение",
    "Upload image" : "Загрузить изображение",
    "From gallery" : "Из галереи",
    "Line" : "Линия",
    "Pen" : "Ручка",
    "Polygon" : "Многоугольник",
    "Sides" : "Количество сторон",
    "Rectangle" : "Прямоугольник",
    "Corner Radius" : "Радиус скругления",
    "Width in pixels" : "Ширина (пикс.)",
    "Height in pixels" : "Высота (пикс.)",
    "Toggle ratio lock" : "Блокировка соотношения сторон",
    "Reset to original image size" : "Вернуться с исходному размеру",
    "Rotate" : "Поворот",
    "Text" : "Текст",
    "Text spacing" : "Межстрочный интервал",
    "Text alignment" : "Выравнивание текста",
    "Font family" : "Гарнитура шрифта",
    "Size" : "Размер",
    "Letter spacing" : "Межсимвольный интервал",
    "Line height" : "Высота строки",
    "Warmth" : "Теплота",
    "+ Add watermark" : "+ Добавить водяной знак",
    "+ Add text watermark" : "+ Добавить текстовый водяной знак",
    "Choose watermark type" : "Выберите тип водяного знака",
    "Upload watermark" : "Загрузить водяной знак",
    "Add as text" : "Добавить как текст",
    "Padding" : "Отступы",
    "Paddings" : "Заполнение",
    "Shadow" : "Тень",
    "Horizontal" : "По горизонтали",
    "Vertical" : "По вертикали",
    "Opacity" : "Непрозрачность",
    "Transparency" : "Прозрачность",
    "Position" : "Расположение",
    "Stroke" : "Зачёркнутый",
    "Save image as" : "Сохранить изображение как",
    "Extension" : "Расширение",
    "Format" : "Формат",
    "Name is required." : "Необходимо указать имя.",
    "Quality" : "Качество",
    "Saved image size (width x height)" : "Размер сохранённого изображения (ширина × высота)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Обратите внимание, что выбранная область обрезки меньше примененного изменения размера, что может привести к снижению качества",
    "Actual size (100%)" : "Фактический размер (100%)",
    "Fit size" : "По размеру окна",
    "Select image to add …" : "Выберите изображение для добавления …",
    "Failed to load image." : "Не удалось загрузить изображение.",
    "Menu" : "Меню",
    "Width" : "Ширина",
    "Height" : "Рост",
    "No preview available for this crop item" : "Предварительный просмотр этого элемента обрезки недоступен"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
